@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -214,7 +214,19 @@ Stretch.prototype.getOperation = function(preview) {
 Stretch.getStrechOperation = function(document, polygon, preview, offset, layerId, op) {
     // limit search to bounding box of polygon:
     var box = polygon.getBoundingBox();
-    var entities = document.queryIntersectedEntitiesXY(box);
+
+    // only stretch selected if there is a selection,
+    // otherwise stretch all:
+    var entities = document.queryIntersectedEntitiesXY(box, false, false, RObject.INVALID_ID, [], document.hasSelection());
+
+    if (entities.length===0 && !preview) {
+        if (document.hasSelection()) {
+            EAction.handleUserWarning(qsTr("No selected entities in given range"));
+        }
+        else {
+            EAction.handleUserWarning(qsTr("No entities in given range"));
+        }
+    }
 
     if (isNull(op)) {
         op = new RAddObjectsOperation();
