@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -366,7 +366,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 
         // grid layout with three columns and N rows for N property controls:
         gridLayoutGeometry = new QGridLayout(this.geometryGroup);
-        gridLayoutGeometry.setVerticalSpacing(4);
+        gridLayoutGeometry.setVerticalSpacing(2);
         gridLayoutGeometry.setColumnStretch(0,0);
         gridLayoutGeometry.setColumnStretch(1,1);
         gridLayoutGeometry.setColumnStretch(2,0);
@@ -381,7 +381,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
         // grid layout with four columns and N rows for N property controls:
         // (the fourth column is for the 'remove property' button)
         gridLayoutChild = new QGridLayout(this.childGroup);
-        gridLayoutChild.setVerticalSpacing(4);
+        gridLayoutChild.setVerticalSpacing(2);
         gridLayoutChild.setColumnStretch(0,0);
         gridLayoutChild.setColumnStretch(1,1);
         gridLayoutChild.setColumnStretch(2,0);
@@ -398,7 +398,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
             // grid layout with four columns and N rows for N property controls:
             // (the fourth column is for the 'remove property' button)
             gridLayoutCustom = new QGridLayout(this.customGroup);
-            gridLayoutCustom.setVerticalSpacing(4);
+            gridLayoutCustom.setVerticalSpacing(2);
             gridLayoutCustom.setColumnStretch(0,0);
             gridLayoutCustom.setColumnStretch(1,1);
             gridLayoutCustom.setColumnStretch(2,0);
@@ -587,7 +587,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                     if (!isNull(controls) && !isNull(gridLayout)) {
                         row = gridLayout.rowCount();
                         var localTitle = title;
-                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId()) {
+                        if (propertyTypeId.isCustom() && group!==RSettings.getAppId() && propertyTypeId.getCustomPropertyTitle()!=="Attributes") {
                             var pos = title.indexOf("_");
                             if (pos!==-1) {
                                 localTitle = title.mid(pos+1);
@@ -597,6 +597,11 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                             localTitle = RSettings.translate("REntity", title);
                         }
 
+                        var l = attributes.getLabel();
+                        if (l.length>0) {
+                            localTitle = l;
+                        }
+
                         var label = new QLabel(localTitle + this.colon, groupBox);
                         label.textInteractionFlags = Qt.TextSelectableByMouse;
                         label.alignment = Qt.AlignRight | Qt.AlignVCenter;
@@ -614,7 +619,9 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
                         }
 
                         // 'remove custom property' button:
-                        if (propertyTypeId.isCustom() && !isNull(gridLayoutCustom) && group===RSettings.getAppId()) {
+                        if (propertyTypeId.isCustom() && !isNull(gridLayoutCustom) &&
+                            group===RSettings.getAppId() && !attributes.isUndeletable()) {
+
                             var removeCustomPropertyButton = new QToolButton(this.widget);
                             removeCustomPropertyButton.icon = new QIcon(this.basePath + "/RemoveCustomProperty.svg");
                             removeCustomPropertyButton.iconSize = new QSize(12,12);
@@ -704,7 +711,7 @@ PropertyEditorImpl.prototype.updateGui = function(onlyChanges) {
 
     // add custom property button:
     if (!onlyChanges) {
-        if (RSettings.isXDataEnabled()) {
+        if (RSettings.isXDataEnabled() && RSettings.getBoolValue("PropertyEditor/AddCustomProperties", true)!==false) {
             var addCustomPropertyButton = new QToolButton(this.widget);
             addCustomPropertyButton.icon = new QIcon(this.basePath + "/AddCustomProperty.svg");
             addCustomPropertyButton.iconSize = new QSize(12,12);
@@ -732,6 +739,12 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
     var attributes = this.getPropertyAttributes(propertyTypeId);
     var controls;
 
+    // used for custom properties only:
+    // invisible flag of other properties is handled in RPropertyEditor:
+    if (attributes.isInvisible()) {
+        return undefined;
+    }
+
     var objectName = PropertyEditorImpl.getControlObjectName(propertyTypeId);
     if (isNull(control) && onlyChanges) {
         // find existing control:
