@@ -1,5 +1,5 @@
 /**
- * Copyright (c) 2011-2017 by Andrew Mustun. All rights reserved.
+ * Copyright (c) 2011-2018 by Andrew Mustun. All rights reserved.
  * 
  * This file is part of the QCAD project.
  *
@@ -84,10 +84,12 @@ function usage() {
 }
 
 /**
- * Open files given as arguments args or creates a new document if
- * no files are given and createNew is true.
+ * Open files given as arguments args
+ *
+ * \param createNew Creates a new document if no files are given
+ * \param close Closes existing open MDI widgets
  */
-function openFiles(args, createNew) {
+function openFiles(args, createNew, close) {
     var appWin = RMainWindowQt.getMainWindow();
     if (isNull(appWin)) {
         // application is shutting down..
@@ -176,7 +178,12 @@ function openFiles(args, createNew) {
 
                 if (fileInfo.absoluteFilePath()===argFileInfo.absoluteFilePath()) {
                     mdiArea.setActiveSubWindow(mdiChildren[k]);
-                    foundExisting = true;
+                    if (close) {
+                        mdiArea.closeActiveSubWindow();
+                    }
+                    else {
+                        foundExisting = true;
+                    }
                     break;
                 }
             }
@@ -294,9 +301,6 @@ function setUpDragAndDrop(appWin) {
  */
 function loadTranslations(addOns, splash) {
     var locale = RSettings.getLocale();
-    if (locale === "en" || locale.toLowerCase() === "en_us") {
-        return;
-    }
 
     if (!isNull(splash)) {
         // no translations yet:
@@ -581,7 +585,7 @@ function main() {
             var s = pluginInfo.get(key);
             if (!isNull(s)) {
                 fn = s;
-                qDebug("splash override: ", fn);
+                //qDebug("splash override: ", fn);
             }
         }
 
@@ -690,7 +694,7 @@ function main() {
 
     setUpDragAndDrop(appWin);
 
-    appWin.windowIcon = new QIcon("scripts/qcad_icon.png");
+    appWin.windowIcon = new QIcon(autoPath("scripts/qcad_icon.png"));
     if (!ignoreDockappWindows) {
         appWin.readSettings();
     }
@@ -742,7 +746,9 @@ function main() {
     // open files given on command line:
     var clickedFilesAndArgs = filesToOpen.concat(args.slice(1));
     QCoreApplication.processEvents();
+    appWin.setProperty("starting", true);
     openFiles(clickedFilesAndArgs, !recovered);
+    appWin.setProperty("starting", false);
 
     RPluginLoader.postInitPlugins(RPluginInterface.LoadedFiles);
 
